#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Jul 24 21:36:07 2022

@author: david
"""
import matplotlib.pyplot as plt
import matplotlib as mpl
import numpy as np
import pandas as pd

# paramètres initiaux

x0,y0 = 1,2 # coordonnées du point origine

v0 = 6.5 # vitesse initiale (m/s)

# tmax = 5# temps maximal (s)

g = 9.81 # accélération de la pesanteur (m/s2)
ax0 = 0 # accélération selon x
ay0 = -g

angle = 45
dt = 2e-3# pas de temps (s)
liste_frottements = np.arange(0,3.2,0.2)
# ----------------------------------------------
plt.rcParams["font.family"] = "Linux Libertine O"
cmap=plt.get_cmap('PRGn') # colormap
norm = mpl.colors.Normalize(vmin=min(liste_frottements),vmax=max(liste_frottements))#normalisation
# ------------------------------------------------------

def acceleration(vx,vy, f):
    """
    renvoie ax, ay selon un modèle de frottements.
    """
    ax = ax0-f*vx
    ay = ay0-f*vy
    return ax, ay

def trajectoire(angle, fr):
    """
    renvoie les positions x, y et les composantes vx et vy de la vitesse
    """
    x=[x0]
    y=[y0]
    vx0 = v0*np.cos(np.radians(angle))
    vx = [vx0]
    vy0 = v0*np.sin(np.radians(angle))
    vy = [vy0]
    ax=[ax0]
    ay=[ay0]
    t = [0]
    k = 0
    f = fr # coeff. de frottements
    while y[k] >= 0:# tant que le projectile n'est pas tombé au sol
        acc_x, acc_y = acceleration(vx[k], vy[k], f)
        vx.append(vx[k] + dt*ax[k])
        vy.append(vy[k] + dt*ay[k])
        # vy.append(vy[k] + dt*ay0)
        x.append(x[k] + dt*vx[k])
        y.append(y[k] + dt*vy[k])
        ax.append(acc_x)
        ay.append(acc_y)
        t.append(t[k] + dt)
        k = k + 1
    return np.array(x), np.array(y), np.array(vx), np.array(vy), np.array(t)


# Paramètres graphiques :
fig = plt.figure(figsize=(29.7/2.54, 21/2.54),tight_layout=True)

# ------------------ GRAPHIQUE 1 ----------------------
axe = plt.subplot(121)
# axe.set_xticks(np.arange(0,6,0.1), minor=True)
axe.set_xticks(np.arange(0,7,0.5), major=True)
axe.set_xlim(x0,7)
plt.suptitle('Trajectoires de lancers avec frottements',
             fontweight='bold')

axe.text(0.01,0.01,f'angle de tir : {angle}°', transform=axe.transAxes)

# tracés des courbes :
for frott in liste_frottements :
    x, y, vx, vy, t= trajectoire(angle, frott)
    axe.plot(x,y, c=cmap(norm(frott)),label=round(frott,2))

ymin,ymax = axe.get_ylim()
axe.set_ylim(0,ymax)
axe.legend(title='coefficient\nde frottements')

axe.text(4.5,2.7,"parabole",c=cmap(norm(min(liste_frottements))))
axe.text(1.5,1.5,"Tartaglia",c=cmap(norm(max(liste_frottements))))


# ------------------ GRAPHIQUE 2 ----------------------

axe2 = plt.subplot(122)
liste_angles = np.arange(10,80,10)
frott = 2.0

norm = mpl.colors.Normalize(vmin=min(liste_angles),vmax=max(liste_angles))#normalisation


# tracés des courbes :
for angle in liste_angles :
    x, y, vx, vy, t= trajectoire(angle, frott)
    axe2.plot(x,y, c=cmap(norm(angle)),label=angle)


ymin,ymax = axe.get_ylim()
axe2.set_ylim(0,ymax)
xmin,xmax = axe.get_xlim()
axe2.set_xlim(1,ymax)
axe2.legend(title='angle')

axe2.axhline(y0,color='gray', ls='--',lw=0.5)
axe2.text(0.01,0.01,f'coeff. frottements : {frott}', transform=axe2.transAxes)


fig.savefig("trajectoires_tartaglia.pdf")
fig.savefig("trajectoires_tartaglia.png",dpi=200)






